{%- set form_state = form_state | default(settings['form-state']) | default('default') -%}
{%- set classes = ['e-con', 'e-atomic-element', base_styles.base, 'form-state-' ~ form_state] | merge(settings.classes | default([])) | join(' ') -%}
<form class="{{ classes }} {{ editor_classes | default('') }}"
      data-id="{{ id }}"
      data-element_type="{{ type }}"
      data-e-type="{{ type }}"
      data-interaction-id="{{ interaction_id }}"
      data-interactions="{{ interactions | json_encode | e('html_attr') }}"
      x-data="eForm{{ id }}"
      x-on:submit="submit"
      {%- if settings['form-name'] is not empty %}
      aria-label="{{ settings['form-name'] | e('html_attr') }}"
      data-form-name="{{ settings['form-name'] | e('html_attr') }}"
      {% endif -%}
      {%- if settings['_cssid'] is not empty %}
      id="{{ settings['_cssid'] | e('html_attr') }}"
      {% endif -%}
      {{ editor_attributes | default('') | raw }}>
    <!-- elementor-children-placeholder -->
</form>
