{% set classes = ['e-con', 'e-atomic-element', base_styles.base] | merge(settings.classes | default([])) | join(' ') %}
<div class="{{ classes }} {{ editor_classes | default('') }}"
     data-id="{{ id }}"
     data-element_type="{{ type }}"
     data-e-type="{{ type }}"
     data-interaction-id="{{ interaction_id }}"
     {{ editor_attributes | default('') | raw }}>
    <div class="e-pro-promotion-placeholder">
        <i class="eicon-upgrade-crown-full e-pro-promotion-placeholder__icon"></i>
        <div class="e-pro-promotion-placeholder__title">Atomic Form is a Pro feature</div>
        <div class="e-pro-promotion-placeholder__description">Upgrade now to access advanced styling and build fully custom forms.</div>
        <div class="e-pro-promotion-placeholder__actions">
            <button type="button" class="e-pro-promotion-placeholder__remove-btn">Remove</button>
            <a href="https://go.elementor.com/go-pro-atomic-form-canvas-upgrade/" target="_blank" rel="noopener noreferrer" class="e-pro-promotion-placeholder__unlock-btn">Unlock with Pro</a>
        </div>
    </div>
</div>
